@@ -102,6 +102,10 @@ static struct _error_message
   0, ""}
 };
 
+#if (PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION <= 4)
+typedef int Py_ssize_t;
+#endif
+
 static PyObject *
 _cubrid_return_PyUnicode_FromString (const char *buf, Py_ssize_t size, 
         const char *encoding, const char *errors)
@@ -444,7 +448,7 @@ Get the cursor class. Return a new Cursor Object.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   cur = con.cursor()\n\
   ...\n\
   other operations\n\
@@ -487,7 +491,7 @@ Create a large object. Return a new lob object.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   cur = con.cursor()\n\
   cur.prepare('insert into test_lob(image) values (?)')\n\
   lob = con.lob()\n\
@@ -585,7 +589,7 @@ Returns a string that represents the server version number.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   print con.server_version()\n\
   con.close()";
 
@@ -618,7 +622,7 @@ Return a string that represents the CUBRID client library\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   print con.client_version()\n\
   con.close()";
 
@@ -650,7 +654,7 @@ mode: string. It will be ON/OFF, TRUE/FALSE, YES/NO\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   con.set_autocommit('ON')\n\
   print con.autocommit\n\
   con.close()";
@@ -718,7 +722,7 @@ isolation_level maybe::\n\
 Example::\n\
   import _cubrid\n\
   form _cubrid import *\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   con.set_isolation_level(CUBRID_REP_CLASS_REP_INSTANCE)\n\
   print con.isolation_level\n\
   con.close()";
@@ -762,7 +766,7 @@ Return values::\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   print con.ping()\n\
   con.close()";
 
@@ -841,7 +845,7 @@ columns that were updated by the previous INSERT query.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb\", \"public\")\n\
+  con = _cubrid.connect(\"CUBRID:localhost:33000:demodb:::\", \"public\")\n\
   cur = con.curosr()\n\
   cur.prepare(\"create table test_cubrid(id NUMERIC\n\
           AUTO_INCREMENT(10300, 1), name VARCHAR(50))\")\n\
@@ -875,7 +879,9 @@ _cubrid_ConnectionObject_last_insert_id (_cubrid_ConnectionObject * self,
   else
     {
       strncpy (ret, name, sizeof (ret) - 1);
+#ifndef _WIN32
       free (name);
+#endif
     }
 
   return _cubrid_return_PyString_FromString (ret);
@@ -1088,7 +1094,7 @@ Return values::\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   print con.schema_info(CUBRID_SCH_TABLE, 'test_cubrid')\n\
   con.close()";
 
@@ -1374,12 +1380,14 @@ _cubrid_CursorObject_reset (_cubrid_CursorObject * self)
 
 static char _cubrid_CursorObject_prepare__doc__[] =
 "prepare(sql)\n\
-This function is sort of API which represents SQL statements compiled\n\
-previously. Accordingly, you can use this statement effectively to\n\
-execute several times repeatedly or to process long data Only a single\n\
-statement can be used and a parameter may put a question mark (?) to\n\
-appropriate area in the SQL statement. Add a parameter when you bind\n\
-a value in the VALUES clause of INSERT statement or in the WHERE clause.\n\
+This function creates a prepared statement. A prepared statement is a\n\
+server-side object that can be used to optimize performance. You can \n\
+use this statement effectively to execute repeatedly or to process \n\
+long data. Only a single statement can be used. The SQL statement can \n\
+contain zero or more question mark (?) parameter markers for which real \n\
+values will be substituted when the statement is executed. Add a \n\
+parameter when you bind a value in the VALUES clause of INSERT statement \n\
+or in the WHERE clause.\n\
 \n\
 sql: string, the sql statement you want to execute.";
 
@@ -1479,7 +1487,7 @@ Parameters::\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   \n\
   cur.prepare('create table test_blob(image BLOB)')\n\
@@ -1631,7 +1639,7 @@ row: int, the column you want to get the information.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_cubrid')\n\
   cur.execute()\n\
@@ -1739,15 +1747,14 @@ _cubrid_CursorObject_result_info (_cubrid_CursorObject * self,
 
 static char _cubrid_CursorObject_execute__doc__[] =
 "execute([option[,max_col_size]])\n\
-execute the prepared SQL statement, which is executing prepare() and\n\
-bind_param()/bind_lob(). The function of retrieving the query result\n\
-from the server through a flag can be classified as synchronous or\n\
-asynchronous. If the flag is set to CUBRID_EXEC_QUERY_ALL, a\n\
-synchronous mode(sync_mode) is used to retrieve query results\n\
-immediately after executing prepared queries. If it is set to\n\
-CUBRID_EXEC_ASYNC, an asynchronous mode (async_mode) is used to\n\
+Executes a prepared Query.\n\
+A option can be used when retrieving the query result from the server.\n\
+A option can be classified as synchronous or asynchronous. \n\
+If the option is set to CUBRID_EXEC_QUERY_ALL, a synchronous mode(sync_mode) \n\
+is used to retrieve query results immediately after executing prepared queries. \n\
+If it is set to CUBRID_EXEC_ASYNC, an asynchronous mode (async_mode) is used to\n\
 retrieve the result immediately each time a query result is created.\n\
-The flag is set to CUBRID_EXEC_QUERY_ALL by default, and in such\n\
+The option is set to CUBRID_EXEC_QUERY_ALL by default, and in such\n\
 cases the following rules are applied:\n\
   - The return value is the result of the first query.\n\
   - If an error occurs in any query, the execution is processed\n\
@@ -1764,7 +1771,7 @@ prepared query is CHAR, VARCHAR, NCHAR, VARNCHAR, BIT or VARBIT.\n\
 If it is set to 0, all data is transferred.\n\
 \n\
 Parameters::\n\
-  flag: Exec flag, flag maybe the following values:\n\
+  option: Exec option, option maybe the following values:\n\
     CUBRID_EXEC_ASYNC\n\
     CUBRID_EXEC_QUERY_ALL\n\
     CUBRID_EXEC_QUERY_INFO\n\
@@ -2088,7 +2095,7 @@ to the next row after getting the result.\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_cubrid')\n\
   cur.execute()\n\
@@ -2153,7 +2160,7 @@ Parameters::\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_lob')\n\
   cur.execute()\n\
@@ -2678,7 +2685,7 @@ It will be create a BLOB object as default.\n\
 \n\
 Example 1::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('insert into test_clob(content) values (?)')\n\
   lob = con.lob()\n\
@@ -2692,7 +2699,7 @@ Example 1::\n\
 \n\
 Example 2::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_blob')\n\
   cur.execute()\n\
@@ -2764,7 +2771,7 @@ file: string, support filepath/file\n\
 \n\
 Example::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_lob')\n\
   cur.execute()\n\
@@ -2840,7 +2847,7 @@ Return a string that contains the data read.\n\
 \n\
 Example 1::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   lob = con.lob()\n\
   lob.imports('README', 'C')\n\
   str = lob.read(32)\n\
@@ -2850,7 +2857,7 @@ Example 1::\n\
 \n\
 Example 2::\n\
   import _cubrid\n\
-  con = _cubrid.connect('CUBRID:localhost:33000:demodb', 'public')\n\
+  con = _cubrid.connect('CUBRID:localhost:33000:demodb:::', 'public')\n\
   cur = con.cursor()\n\
   cur.prepare('select * from test_lob')\n\
   cur.execute()\n\
@@ -3391,7 +3398,7 @@ PyTypeObject _cubrid_CursorObject_type = {
   0,				/* tp_free */
 };
 
-#define _CUBRID_VERSION_	"8.4.3.0002"
+#define _CUBRID_VERSION_	"8.4.3.0003"
 static char _cubrid_doc[] = "CUBRID API Module for Python";
 
 #if PY_MAJOR_VERSION >= 3
